# Standard library imports
import sys
import os

def main():  # type: () -> None
    funcs = [a for a in sys.argv[1:] if not a.startswith("-")]
    opts = [o for o in sys.argv[1:] if o.startswith("-")]
    # Show help message

    current_dir = os.path.dirname(os.path.abspath(__file__))
    if funcs:
        method = funcs[0]
        os.system("python {}/{}.py {}".format(current_dir, method, ' '.join(sys.argv[2:])))
    else:
        if "-h" in opts or "--help" in opts:
            is_detail = "-a" in opts
            print("No repeat package contains cmd:")
            for _, _, files in os.walk(current_dir):
                f_s_files = sorted([file for file in files if
                             not file.startswith('__')
                             and file.endswith('.py')])
                for f_s in f_s_files:
                    method = f_s.split('.')[0]
                    print(method)
                    if is_detail:
                        code = "python {}/{}.py {}".format(current_dir, method, ' '.join(sys.argv[1:]))
                        os.system(code)
                        print("*" * 60)
            if not is_detail:
                print("use norepeat -h -a to see more detail info OR norepeat rename_file -h to see one ")
        else:
            print("Use -h to have a look")

if __name__ == "__main__":
    main()


# coding:utf-8
import os
import argparse

# 定义外部变量，做全局记录用
code_lines = 0


# 定义函数
def get_lines_by_suffix(path, suffix):
    # 设置code_lines为全局变量
    global code_lines
    # 列出path下的文件和文件夹，不包括子文件和子文件夹
    file_list = os.listdir(path)
    # 遍历列出的文件及文件夹，如果是文件夹，递归查找，如果是文件，则统计代码行数
    for filename in file_list:
        # path和filename，共同组成查询出的某个文件或文件夹完整路径
        file_path = os.path.join(path, filename)
        # 如果是文件夹
        if os.path.isdir(file_path):
            # 递归查找
            get_lines_by_suffix(file_path, suffix)
        else: # 是文件
            # 判断后缀
            if file_path.split(".")[-1] == suffix:
                # 统计代码行数
                code_lines += get_lines(file_path)
                # 打印查看
                print(code_lines, file_path)
    # 递归查找完毕，返回全部代码条数
    return code_lines


# 定义函数，用于计算单个文件中的代码的函数
def get_lines(file):
    # 打开（连接）文件
    with open(file, encoding="utf-8") as f:
        # 获取读取到的行数，也即文件中代码的行数
        return len(f.readlines())

if __name__ == '__main__':
    description = """
    Count summary codes lines/统计代码行数
    Eg:
        norepeat count_code_nums -p=project -t=py
    """
    parser = argparse.ArgumentParser(description=description,
                                     prog='count_code_nums',
                                     formatter_class=argparse.RawDescriptionHelpFormatter,
                                     )

    parser.add_argument('-p', '--path', help='file/directory path')
    parser.add_argument('-t', '--type', help='file type', default='py')
    args = parser.parse_args()
    if args.path and args.type:
        # 测试验证
        src_path = args.path if args.path !='.' else os.getcwd()
        code_lines = get_lines_by_suffix(src_path, args.type)
        print(code_lines)
    else:
        print('Invalid path or type, use -h to have a try')




import os
import shutil
import argparse



def merge_dir(path, dst_path):
    files = os.listdir(path)
    for f in files:
        sub_path = path + "/" + f
        if os.path.isdir(sub_path):
            merge_dir(sub_path, dst_path)
        else:
            src_path = path + "/" + f
            if not os.path.exists(dst_path):
                os.makedirs(dst_path)

            if os.path.exists(dst_path + "/" + f): # If dst file already
                continue
            shutil.copy(src_path, dst_path)
            print(src_path)

if __name__ == '__main__':
    description = """
    Merge all dirs files to a same directory named 'merge'
    Eg:
        norepeat split_dir -p=test
        before:
            dir
                txt
                    txt2
                        c.txt
                    a.txt
                    b.txt
                png
                    a.png
                    b.png
        after:
            dir
                merge
                    a.txt
                    b.txt
                    c.txt
                    a.png
                    b.png
    """
    parser = argparse.ArgumentParser(description=description,
                                     prog='merge_dir',
                                     formatter_class=argparse.RawDescriptionHelpFormatter,
                                     )

    parser.add_argument('-p', '--path', help='dir path, use . for current dir')

    args = parser.parse_args()
    try:
        if not args.path:
            raise Exception('Missing params path')
        src_path = args.path if args.path !='.' else os.getcwd()
        dst_path = src_path + "/merge"
        merge_dir(src_path, dst_path)
    except Exception as e:
        print(str(e))
        print('Use -h to have a try')



# -*- coding:utf-8 -*-
import re
import argparse
d = {"#": 1, "##": 2, "###": 3, "####": 4, "#####": 5, "######": 6}
pattern = '#+\s'


def gan_menu(filename):
    targetname = filename.split('.')[0] + "_bak.md"
    with open(targetname, 'w+') as f2:
        with open(filename, 'r') as f:
            for i in f.readlines():
                if not re.match(pattern, i.strip(' \t\n')):
                    continue
                i = i.strip(' \t\n')
                head = i.split(' ')[0]
                f2.write(' ' * (len(head) - 1) + '- ' +
                         '[' + i[len(head):].strip(' \t\n') + '](#' + i[len(head):].strip(' \t\n') + ')   \n')
        with open(filename, 'r') as f:
            for i in f.readlines():
                f2.write(i)


if __name__ == '__main__':
    description = """
    Generate markdown Menu automatically/自动生成markdown 目录
    Eg:
        norepeat gen_markdown_menu -n=sample.md  
        - [Python](#python)
            - [markdown](#markdown)
    
    then you will get a sample_back.md with contents
    sample_back.md is new generated file including menu
    """

    parser = argparse.ArgumentParser(description=description,
                                     prog='gen_markdown_menu',
                                     formatter_class=argparse.RawDescriptionHelpFormatter,
                                     )
    parser.add_argument('-n', '--name', help='file name')
    args = parser.parse_args()

    try:
        gan_menu(args.name)
    except Exception as e:
        print(str(e))


"""Setup script for realpython-reader"""

import os.path
from setuptools import setup, find_packages

# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))

# The text of the README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

# This call to setup() does all the work
# https://packaging.python.org/tutorials/packaging-projects/
setup(
    name="norepeat",
    version="1.0.6",
    description="Less codes make more tools",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/DasyDong/python-norepeat",
    author="Dasy Dong",
    author_email="dasydong@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
    entry_points={"console_scripts": ["norepeat=norepeat.__main__:main"]},
)